commands/init_command library

Provides the entry point for initializing the project structure and dependencies.

This command will create the recommended folder structure and inject essential dependencies into pubspec.yaml, including a user choice for state management helper (equatable or freezed).

Functions

runInitCommand() → void
Initializes the project structure and injects dependencies.