helpers/state_helper library
State management helper selection for Blocraft CLI.
Provides a class and function to handle user choice between equatable and freezed.
Classes
- StateHelperChoice
- Represents the user's choice for state management helper dependencies.
Functions
-
chooseStateHelper(
) → StateHelperChoice - Prompts the user to choose a state management helper and returns the corresponding dependencies.